import json
import os


def get_json(client, path: str):
    print("Calling '{}' ...".format(path))
    response = client.get(path)
    assert 200 <= response.status_code < 300
    return json.loads(response.data.decode())


def post_json(client, path: str, doc: dict):
    response = client.post(path, data=json.dumps(doc), content_type="application/json")
    assert 200 <= response.status_code < 300
    return json.loads(response.data.decode())


tests_dir = os.path.abspath(os.path.dirname(__file__))



import hashlib
from unittest.mock import patch

from karp5.context.auth.std_auth import check_user


def test_hashlib_md5():
    user = "User"
    pwd = "Pwd"
    secret = "Secret"
    user_pwd_secret = user + pwd + secret

    result = hashlib.md5((user + pwd + secret).encode("utf-8")).hexdigest()
    assert result is not None


def test_check_user_empty_call(app):
    result = None
    assert result is None
